@@ -1052,7 +1052,7 @@ class Tensor(torch.Tensor):
 
             if isinstance(ret, (tuple, list)):
                 # Also handles things like namedtuples
-                return type(ret)(Tensor.__torch_function_convert__(r, col) for r in ret)
+                return type(ret)(Tensor.__torch_function_convert_collect__(r, col, cls) for r in ret)
 
             return ret
 
